@@ -32,12 +32,12 @@ pub use crate::entry_def_index;
 pub use crate::entry_defs;
 pub use crate::entry_type;
 pub use crate::hash_path::anchor::anchor;
-pub use crate::hash_path::anchor::get_anchor;
 pub use crate::hash_path::anchor::list_anchor_addresses;
 pub use crate::hash_path::anchor::list_anchor_tags;
 pub use crate::hash_path::anchor::list_anchor_type_addresses;
 pub use crate::hash_path::anchor::Anchor;
 pub use crate::hash_path::path::Path;
+pub use crate::hash_path::path::PathEntry;
 pub use crate::hdk::*;
 pub use crate::info::agent_info;
 pub use crate::info::call_info;
